/**
 * \addtogroup Timers
 * @{
 */

/*****************************************************************************/
/**
 * \file Timers.h
 * Quad pseudo timer routines for 8051 and Keil C compiler.
 * \author Copyright (c) 2009, Murray R. Van Luyn. <vanluynm@iinet.net.au>
 * \version 0.2
 * \date 23-06-09
 */
/*****************************************************************************/

/*****************************************************************************
 *
 *     THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 *     OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *     ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 *     DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *     DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 *     GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *     INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *     WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *     NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

#ifndef TIMERS_H
#define TIMERS_H

#include <REG51.h>

/*****************************************************************************
 *
 *                           Constant Definitions
 *
 *****************************************************************************/

/** 
 * Hardware crystal frequency in Hz.
 * Adjust \b XTAL to match hardware.
 * \hideinitializer
 */
#define XTAL                 18432000    

/*
 * Timer 0 mode 1 clock rate.
 */
#define T1_CLOCK             XTAL / 12   

/*
 * Timer 0 reload calculation defines.
 */
#define CYCLES_FOR_OVERFLOW 65535
#define CYCLES_FOR_1MS    0.001  * T1_CLOCK
#define TIMER_0_RELOAD    (unsigned int)(CYCLES_FOR_OVERFLOW - CYCLES_FOR_1MS)


/*****************************************************************************
 *
 *                           Global Variable Declarations
 *
 *****************************************************************************/


/*****************************************************************************
 *
 *                           Public Function Prototypes
 *
 *****************************************************************************/
/**
 * Quad pseudo timer routine initialisation function.
 * Initialises the 8051 timer for 1ms periodic interrupt.
 * Must be called once to set-up hardware during program initialisation.
 * \param -
 * \return -
 */
extern void timers_init(void);

/**
 * Quad pseudo timer routine restart function.
 * Restarts selected pseudo timer for expiry after given period.
 * \param timer An \b unsigned \b char indicating timer to restart.
 * \param period An \b unsigned \b int specifying period for timer to run.
 * \return -
 */
extern void timers_restart_timer(unsigned char timer, unsigned int period);

/**
 * Quad pseudo timer routine expired test function.
 * Returns true when selected pseudo timer has expired.
 * \param timer An \b unsigned \b char indicating timer to test.
 * \return A \b bit returning true when timer expired.
 */
extern bit timers_is_expired_timer(unsigned char timer);


#endif

/** @} */
